"""\
flake8-postponed-annotations package.

Checks for literal string usage in type annotations
"""

plugin_prefix = 'PAE'
